QueryClientAbstract<T> class abstract

Implementers

Constructors

QueryClientAbstract(Future<T> fn(QueryClientAbstract<T> client), {bool manual = false, bool swr = true, bool infinity = false, void onUpdate() = noop})

Properties

clean → void Function()
仅重置所有数据,包含 error 和 data
no setter
data → T
本次请求的数据
no setter
error → dynamic
错误信息
no setter
future Future<T>
no setter
hashCode int
The hash code for this object.
no setterinherited
isError bool
是否报错
no setter
loading bool
当前正在全新加载数据
no setter
loadMore Future<T> Function()
增量请求
no setter
pages List<T>
如果 infinity 模式为 false 则该数组中最多只会有一个元素,该元素与 data 为同一个元素 如果 infinity 模式为 true 则该数组中存放着所有分页获取的数据
no setter
request Future<T> Function()
全新请求
no setter
reset → void Function()
重置所有数据及状态,包含 error、data、loading 状态等
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validating bool
当前已有数据,并且正在拉取最新数据 infinity 模式下,当已经拉到过一条数据后,后续的请求都会是 validating 为 true
no setter

Methods

mutate<R>(Future<R> fn(QueryClientAbstract<T> client)) Future<R>
修改本地数据
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited